using Exam.Api;
using Scalar.AspNetCore;
using Serilog;


Log.Logger = new LoggerConfiguration()
    .WriteTo.Console()
    .CreateBootstrapLogger();

try
{
    Log.Information("exam service is Starting up");

    var builder = WebApplication.CreateBuilder(args);

    builder.Host
        .ConfigureAppConfiguration((hostBuilderContext, configBuilder) =>
        {
            var path = Path.Combine(Directory.GetCurrentDirectory(), "config");
            configBuilder.SetBasePath(path)
#if DEBUG
                .AddJsonFile("appsettings.shared.Development.json", true, true)
#else
                .AddJsonFile("appsettings.shared.json", true, true)
#endif
                .AddJsonFile("appsettings.json", false, true)
                .AddJsonFile($"appsettings.{hostBuilderContext.HostingEnvironment.EnvironmentName}.json", true, true)
                .AddEnvironmentVariables()
                .AddCommandLine(args)
                ;
        })
        .UseSerilog((ctx, lc) => lc
            //.WriteTo.Console(outputTemplate: "[{Timestamp:HH:mm:ss} {Level}] {SourceContext}{NewLine}{Message:lj}{NewLine}{Exception}{NewLine}")
            .Enrich.FromLogContext()
            .ReadFrom.Configuration(ctx.Configuration), true)
        ;
    //builder.Services.AddControllers().AddNewtonsoftJson();
    builder
        .ConfigureServices()
        .ConfigurePipelines()
        .Run();

    //// Add services to the container.

    //builder.Services.AddControllers();
    //// Learn more about configuring OpenAPI at https://aka.ms/aspnet/openapi
    //builder.Services.AddOpenApi();

    //var app = builder.Build();

    //// Configure the HTTP request pipeline.
    //if (app.Environment.IsDevelopment())
    //{
    //    app.MapOpenApi();
    //    app.MapScalarApiReference(endpointPrefix: "swagger");
    //}

    //app.UseAuthorization();

    //app.MapControllers();

    //app.Run();

}
catch (Exception ex)
{
    Log.Fatal(ex, "Unhandled exception");
    throw;
}
finally
{
    Log.Information("Shut down complete");
    Log.CloseAndFlush();
}



